Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8967)

Unified Diff: chrome/test/data/extensions/api_test/permissions/enabled/background.js

Issue 22584002: Move processes API to dev channel (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebased again Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/test/data/extensions/api_test/permissions/enabled/background.js
diff --git a/chrome/test/data/extensions/api_test/permissions/enabled/background.js b/chrome/test/data/extensions/api_test/permissions/enabled/background.js
index bceed89323f3054b3275927bb91fae9305fe5554..b4dd2146b701ab3ee2e3774835d47618f4e3378c 100644
--- a/chrome/test/data/extensions/api_test/permissions/enabled/background.js
+++ b/chrome/test/data/extensions/api_test/permissions/enabled/background.js
@@ -10,12 +10,12 @@ var pass = chrome.test.callbackPass;
chrome.test.runTests([
function experimental() {
// Test that use of an experimental API works.
// If/when chrome.experimental.processes is moved out of
// experimental, this test needs to be updated.
chrome.tabs.getSelected(null, function(tab) {
try {
- chrome.experimental.processes.getProcessIdForTab(
- tab.id, pass(function(pid) {}));
+ chrome.experimental.accessibility.getAlertsForTab(
+ tab.id, pass(function(alerts) {}));
} catch (e) {
chrome.test.fail();
}
@@ -10,12 +10,12 @@ var pass = chrome.test.callbackPass;
function experimental() {
// Test that use of an experimental API works.
- // If/when chrome.experimental.processes is moved out of
+ // If/when chrome.experimental.accessibility is moved out of
// experimental, this test needs to be updated.
chrome.tabs.getSelected(null, function(tab) {

Powered by Google App Engine
This is Rietveld 408576698